c    mainf.f -- Single-profile fortran interface for lidar multiple
c    scattering algorithm
c
c    Copyright (C) 2004-2005 Robin Hogan <r.j.hogan@reading.ac.uk>
c
c     This library is free software; you can redistribute it and/or
c     modify it under the terms of the GNU Lesser General Public
c     License as published by the Free Software Foundation; either
c     version 2 of the License, or (at your option) any later version.
c
c     This library is distributed in the hope that it will be useful,
c     but WITHOUT ANY WARRANTY; without even the implied warranty of
c     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
c     Lesser General Public License for more details.
c
c     You should have received a copy of the GNU Lesser General Public
c     License along with this library; if not, write to the Free Software
c     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
c
c
c    Fortran interface to lidar multiple scattering algorithm
c     
c    Input data (standard input)
c      First line:
c        num_gates wavelength(um) laser_divergence(rad) telescope_fov(rad) lidar_alt(m)
c      Subsequent lines:
c        range(m) ext(m-1) radius(um) ext_bscat_ratio(sr) ext_air(m)
c
c    Output data (standard output)
c        igate range(m) ext(m-1) radius(um) bscat_total(m-1sr-1)

      program multiscatterf
      implicit none

c     Options for multiple scattering module; note that the numbers
c     should match those given in the C header "multiscatter.h"
      integer MS_INTERMEDIATE_FOV, MS_WIDE_FOV, MS_CRUDE_OPTICAL_DEPTH,
     &     MS_CRUDE_INTEGRATION, MS_NO_MULTISCAT_WITHIN_GATE,
     &     MS_DOUBLE_SCATTERING_ONLY, MS_CRUDE_DOUBLE_SCATTERING,
     &     MS_NUMERICAL_JACOBIAN, MS_NO_MOLECULAR_EXTINCTION
      parameter(MS_INTERMEDIATE_FOV = 0,
     &     MS_WIDE_FOV = 1,
     &     MS_CRUDE_OPTICAL_DEPTH = 2,
     &     MS_CRUDE_INTEGRATION = 3,
     &     MS_NO_MULTISCAT_WITHIN_GATE = 4,
     &     MS_DOUBLE_SCATTERING_ONLY = 5,
     &     MS_CRUDE_DOUBLE_SCATTERING = 6,
     &     MS_NUMERICAL_JACOBIAN = 7,
     &     MS_NO_MOLECULAR_EXTINCTION = 8)

      integer n, i
      real*8 wavelength, rho_laser, rho_telescope, lidar_altitude
      real*8 range(1000), radius(1000), ext(1000)
      real*8 ext_bscat_ratio(1000), ext_air(1000)
      real*8 bscat(1000)

      read(*,*) n, wavelength, rho_laser, rho_telescope, lidar_altitude

      do i = 1,n
         read(*,*) range(i), ext(i), radius(i),
     &        ext_bscat_ratio(i), ext_air(i)
      end do

c     Uncomment the following line for lidars in which most of the
c     forward scattered photons will remain in the lidar field of view
!      call ms_set_wide_fov

c     To set any of the options for the multiple scattering module, use
c     multiple calls of something this:
!      call ms_add_option(MS_CRUDE_OPTICAL_DEPTH)
!      call ms_add_option(MS_WIDE_FOV)

      call multiscatter(n, wavelength, rho_laser, 
     $     rho_telescope, lidar_altitude, range, radius,
     $     ext, ext_bscat_ratio, ext_air, bscat)

      do i = 1,n
         write(*,'(I4, 6E11.4)') i, range(i), ext(i), radius(i),
     $        bscat(i)
      end do

      stop
      end

